@@ -1,14 +1,25 @@
 /*
- * Copyright (C) 2003 Ian Wadham and Marco Krger <ianw2@optusnet.com.au>
- */
+    Copyright 2002 Marco Krüger <grisuji@gmx.de>
+    Copyright 2002 Ian Wadham <ianw2@optusnet.com.au>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #ifndef _KGOLDRUNNER_H_
 #define _KGOLDRUNNER_H_
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // Status bar
 const int ID_LIVES      = 0;            // Field IDs in KDE status bar.
 const int ID_SCORE      = 1;
@@ -20,10 +31,14 @@ const int L_LIVES       = 15;		// Lengths of fields.
 const int L_SCORE       = 17;
 const int L_LEVEL       = 15;
 
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <kxmlguiwindow.h>
 #include <kstandarddirs.h>
-#include <kaction.h>
+#include "kgrconsts.h"
+
+class QAction;
+class KAction;
+class KToggleAction;
+class KToggleFullScreenAction;
 
 class KGrGame;
 class KGrCanvas;
@@ -37,7 +52,7 @@ class KGrHero;
  * @author $AUTHOR <$EMAIL>
  * @version $APP_VERSION
  */
-class KGoldrunner : public KMainWindow
+class KGoldrunner : public KXmlGuiWindow
 {
     Q_OBJECT
 public:
@@ -51,6 +66,9 @@ public:
      */
     virtual ~KGoldrunner();
 
+    /**
+     * Used to indicate if the class initialised properly.
+     */
     bool startedOK() {return (startupOK);}
 
 protected:
@@ -58,32 +76,32 @@ protected:
      * This function is called when it is time for the app to save its
      * properties for session management purposes.
      */
-    void saveProperties(KConfig *);
+    void saveProperties (KConfigGroup &);
 
     /**
      * This function is called when this app is restored.  The KConfig
      * object points to the session management config file that was saved
      * with @ref saveProperties.
      */
-    void readProperties(KConfig *);
+    void readProperties (const KConfigGroup &);
 
-    bool queryClose ();		// To save edits before closing.
+    /// To save edits before closing.
+    bool queryClose();
 
 private slots:
+    // An extension of the constructor.  Gives us two scans of the event queue.
+    void KGoldrunner_2();
+
     // Slot to pause or restart the game.
     void stopStart();
 
+    // Slot to change the graphics theme.
+    void changeTheme (const QString & themeFilepath);
+
     // Local slots to create or edit game information.
     void createGame();
     void editGameInfo();
 
-    // Local slots to set the landscape (colour scheme).
-    void lsKGoldrunner();
-    void lsApple2();
-    void lsIceCave();
-    void lsMidnight();
-    void lsKDEKool();
-
     // Local slots to set mouse/keyboard control of the hero.
     void setMouseMode();
     void setKeyBoardMode();
@@ -99,10 +117,6 @@ private slots:
     void setTradRules();
     void setKGrRules();
 
-    // Local slots to make playing area larger or smaller.
-    void makeLarger();
-    void makeSmaller();
-
     // Local slots for hero control keys.
     void goUp();
     void goR();
@@ -123,15 +137,15 @@ private slots:
     void showEnemy5();
     void showEnemy6();
 
-    void optionsShowToolbar();
-    void optionsShowStatusbar();
+    // void optionsShowToolbar();
+    // void optionsShowStatusbar();
     void optionsConfigureKeys();
-    void optionsConfigureToolbars();
-    void optionsPreferences();
-    void newToolbarConfig();
+    // void optionsConfigureToolbars();
+    // void optionsPreferences();
+    // void newToolbarConfig();
 
-    void changeStatusbar(const QString& text);
-    void changeCaption(const QString& text);
+    void changeStatusbar (const QString& text);
+    void changeCaption (const QString& text);
 
     void showLevel (int);		// Show the current level number.
     void showLives (long);		// Show how many lives are remaining.
@@ -141,13 +155,16 @@ private slots:
     void adjustHintAction (bool);	// Enable/disable "Hint" action.
     void markRuleType (char ruleType);	// Check game's rule type in the menu.
     void setEditMenu (bool on_off);	// Enable/disable "Save Edits" action.
+    void setEditIcon (const QString & actionName, const char iconType);
+    void viewFullScreen (bool activation);
+
+    QSize sizeHint() const;
 
 private:
-    void setupAccel();
     void setupActions();
     void initStatusBar();
-    void makeEditToolbar();
-    void setButton (int btn);
+    void setupEditToolbarActions();
+    void setupThemes();
 
 private:
     bool startupOK;
@@ -160,28 +177,26 @@ private:
     QString systemDataDir;		// Where the system levels are stored.
     QString userDataDir;		// Where the user levels are stored.
 
-    KAction *		saveGame;	// Save game, level, lives and score.
+    QAction *		saveGame;	// Save game, level, lives and score.
 
+    // A KAction is needed here, to get access to KShortcut::setAlternate().
     KAction *		myPause;	// Pause or resume the game.
     QString		pauseKeys;	// Keystroke names to put in status bar.
 
-    KAction *		hintAction;	// Display a hint, if available.
-    KAction *		killHero;	// Kill hero (disabled during edits).
-    KAction *		highScore;	// High scores (disabled during edits).
+    QAction *		hintAction;	// Display a hint, if available.
+    QAction *		killHero;	// Kill hero (disabled during edits).
+    QAction *		highScore;	// High scores (disabled during edits).
 
-    KAction *		saveEdits;	// Save a level that has been edited.
+    QAction *		saveEdits;	// Save a level that has been edited.
 
-    KRadioAction *	setKGoldrunner;	// Show default "KGoldrunner" landscape.
-    KRadioAction *	setAppleII;	// Show "Apple II" landscape.
-    KRadioAction *	setIceCave;	// Show "Ice Cave" landscape.
-    KRadioAction *	setMidnight;	// Show "Midnight" landscape.
-    KRadioAction *	setKDEKool;	// Show "KDE Kool" landscape.
+    KToggleFullScreenAction *fullScreen; // Show Full Screen Mode on menu.
+    KToggleAction *	setMouse;	// Show mouse/keyboard mode on menu.
+    KToggleAction *	setKeyboard;	// Show mouse/keyboard mode on menu.
 
-    KRadioAction *	setMouse;	// Show mouse/keyboard mode on menu.
-    KRadioAction *	setKeyboard;	// Show mouse/keyboard mode on menu.
+    KToggleAction *	tradRules;	// Set Traditional rules.
+    KToggleAction *	kgrRules;	// Set KGoldrunner rules.
 
-    KRadioAction *	tradRules;	// Set Traditional rules.
-    KRadioAction *	kgrRules;	// Set KGoldrunner rules.
+    KToggleAction *	setSounds;	// enable/disable sound effects.
 
     KGrHero *	hero;			// Pointer to the hero.
 
@@ -189,8 +204,7 @@ private:
     // KToggleAction *	m_statusbarAction;
 
     KToolBar *		editToolbar;	// Toolbar for creating/editing levels.
-    int			pressedButton;	// ID of currently set toolbar button.
-
+    KToggleAction *     m_defaultEditAct;
 private slots:
     void freeSlot();			// Set editObj to Free Space.
     void edheroSlot();			// Set editObj to Hero.
