@@ -1,42 +1,59 @@
+/*
+ * Permission to use, copy, modify, and distribute this software and its
+ * documentation for any purpose and without fee is hereby granted,
+ * provided that the above copyright notice appear in all copies and that
+ * both that copyright notice and this permission notice appear in
+ * supporting documentation.
+ *
+ * This file is provided AS IS with no warranties of any kind.  The author
+ * shall have no liability with respect to the infringement of copyrights,
+ * trade secrets or any patents by this file or any part thereof.  In no
+ * event will the author be liable for any lost revenue or profits or
+ * other special, indirect and consequential damages.
+*/
 #include "clock.h"
 #include <klocale.h>
 #include "deck.h"
+#include "patsolve/clock.h"
 #include <assert.h>
-#include "cardmaps.h"
 
-Clock::Clock( KMainWindow* parent, const char *name )
-    : Dealer( parent, name )
+Clock::Clock( )
+    : DealerScene( )
 {
-    const int dist_x = cardMap::CARDX() * 11 / 10 + 1;
-    const int dist_y = cardMap::CARDY() * 11 / 10 + 1;
+    const qreal dist_x = 11.1;
+    const qreal dist_y = 11.1;
 
-    deck = Deck::new_deck(this);
-    deck->move(10, 10+dist_y*3);
-    deck->hide();
+    Deck::create_deck(this);
+    Deck::deck()->setPos(1, 1+dist_y*3);
+    Deck::deck()->hide();
 
     for (int i=0; i<12; i++) {
         target[i] = new Pile(i+1, this);
         const double ys[12] = {   0./96,  15./96,  52./96, 158./96, 264./96, 301./96, 316./96, 301./96, 264./96, 158./96,  52./96,  15./96};
         const double xs[12] = { 200./72, 280./72, 360./72, 400./72, 360./72, 280./72, 200./72, 120./72, 40./72, 0./72, 40./72, 120./72};
-        target[i]->move(15 + cardMap::CARDX() * 24 / 5 + xs[i] * cardMap::CARDX(), 10 + ys[i] * cardMap::CARDY());
+        target[i]->setPilePos(1.2 + 10 * 24 / 5 + xs[i] * 10, 1 + ys[i] * 10);
         target[i]->setCheckIndex(1);
         target[i]->setTarget(true);
         target[i]->setRemoveFlags(Pile::disallow);
+        target[i]->setObjectName( QString( "target%1" ).arg( i ) );
     }
 
     for (int i=0; i<8; i++) {
         store[i] = new Pile(14+i, this);
-        store[i]->move(15+dist_x*(i%4), 10 + cardMap::CARDY() * 5 / 2 * (i/4));
+        store[i]->setPilePos(1.2+dist_x*(i%4), 1 + 10 * 5 / 2 * (i/4));
         store[i]->setAddFlags(Pile::addSpread);
         store[i]->setCheckIndex(0);
+        store[i]->setReservedSpace( QSizeF( 10, 18 ) );
+        store[i]->setObjectName( QString( "store%1" ).arg( i ) );
     }
 
-    setActions(Dealer::Hint | Dealer::Demo);
+    setActions(DealerScene::Hint | DealerScene::Demo);
+    setSolver( new ClockSolver( this ) );
 }
 
 void Clock::restart()
 {
-    deck->collectAndShuffle();
+    Deck::deck()->collectAndShuffle();
     deal();
 }
 
@@ -66,16 +83,16 @@ void Clock::deal() {
 					  Card::Five, Card::Six, Card::Seven, Card::Eight};
 
     int j = 0;
-    while (!deck->isEmpty()) {
-        Card *c = deck->nextCard();
+    while (!Deck::deck()->isEmpty()) {
+        Card *c = Deck::deck()->nextCard();
         for (int i = 0; i < 12; i++)
             if (c->rank() == ranks[i] && c->suit() == suits[i]) {
-                target[i]->add(c, false, true);
+                target[i]->add(c, false);
                 c = 0;
                 break;
             }
         if (c)
-            store[j++]->add(c, false, true);
+            store[j++]->add(c, false);
         if (j == 8)
             j = 0;
     }
@@ -85,7 +102,7 @@ static class LocalDealerInfo11 : public DealerInfo
 {
 public:
     LocalDealerInfo11() : DealerInfo(I18N_NOOP("G&randfather's Clock"), 11) {}
-    virtual Dealer *createGame(KMainWindow *parent) { return new Clock(parent); }
+    virtual DealerScene *createGame() { return new Clock(); }
 } gfi11;
 
 #include "clock.moc"
