@@ -177,7 +177,9 @@ void App::restartGame()
 	while(board->canUndo())
 		board->undo();
 	board->setUpdatesEnabled(true);
+	board->resetRedo();
 	board->update();
+	board->resetTimer();
 	enableItems();
 }
 
