@@ -1,8 +1,29 @@
-#include <math.h>
+/*
+    Copyright (C) 1998-2001 Andreas Zehender <az@azweb.de>
+
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+*/
 
 #include "ai.h"
+
+#include <math.h>
+
+#include <QVector>
+
 #include "mathroutines.h"
 #include "options.h"
+#include "structs.h"
 
 int Ai::calcFrameIncrement[Options::EnumAiDifficulty::COUNT] = {15,8,6,2};
 int Ai::calcPositionNumber[Options::EnumAiDifficulty::COUNT] = {10,15,20,60};
@@ -10,8 +31,8 @@ int Ai::calcShotDirections[Options::EnumAiDifficulty::COUNT] = {4,7,10,12};
 int Ai::calcCollisions[Options::EnumAiDifficulty::COUNT]     = {30,15,10,10};
 int Ai::calcNextShot[Options::EnumAiDifficulty::COUNT]       = {300,200,90,60};
 
-Ai::Ai(int pn,ShipSprite* s[2],QPtrList<BulletSprite>* b[2],
-       QPtrList<MineSprite>* m[2],SConfig *c)
+Ai::Ai(int pn,ShipSprite* s[2],QList<BulletSprite*>* b[2],
+       QList<MineSprite*>* m[2],SConfig *c)
 {
    int i;
 
@@ -24,14 +45,31 @@ Ai::Ai(int pn,ShipSprite* s[2],QPtrList<BulletSprite>* b[2],
       ship[i]=s[i];
       bullets[i]=b[i];
       mines[i]=m[i];
-      shipsNextPositions[i]=new QMemArray<AiSprite>
+      shipsNextPositions[i]=new QVector<AiSprite>
          ((int)(calcPositionNumber[Options::aiDifficulty(playerNumber)]/cfg->gamespeed));
-      aiMines[i]=new QMemArray<AiSprite>(cfg->maxMines);
+      aiMines[i]=new QVector<AiSprite>(cfg->maxMines);
       mineNumber[i]=0;
    }
-   myShots.setAutoDelete(true);
-   objectsHitByShip.setAutoDelete(true);
-   minesHitByShot.setAutoDelete(true);
+}
+
+Ai::~Ai()
+{
+   int i;
+   
+   for (i=0;i<2;i++)
+   {
+      delete shipsNextPositions[i];
+      delete aiMines[i];
+   }
+   
+   qDeleteAll(myShots);
+   myShots.clear();
+   
+   qDeleteAll(objectsHitByShip);
+   objectsHitByShip.clear();
+   
+   qDeleteAll(minesHitByShot);
+   minesHitByShot.clear();
 }
 
 void Ai::newRound()
@@ -40,7 +78,7 @@ void Ai::newRound()
    rotateFramesNumber=0;
    shoot=false;
    score=1e10;
-   
+
    rotation=RNONE;
    acc=false;
    bullet=false;
@@ -51,26 +89,30 @@ void Ai::newRound()
 
    calculateCollisions=(int)(calcCollisions[Options::aiDifficulty(playerNumber)]
                              /cfg->gamespeed);
-   waitShot=(int) rint( random.getDouble() * 
+   waitShot=(int) rint( random.getDouble() *
 	          calcNextShot[Options::aiDifficulty(playerNumber)]
                   /cfg->gamespeed);
 
+   qDeleteAll(myShots);
    myShots.clear();
+   qDeleteAll(objectsHitByShip);
    objectsHitByShip.clear();
+   qDeleteAll(minesHitByShot);
    minesHitByShot.clear();
 }
 
 void Ai::think()
 {
    setSpriteFieldSize();
-   
+
+   qDeleteAll(myShots);
    myShots.clear();
    borderTime=-1;
    sunTime=-1;
    score--;
    if(waitShot>0)
       waitShot--;
-   
+
    calculateNextPositions();
    if(Options::aiDifficulty(playerNumber)!=Options::EnumAiDifficulty::Trainee)
       testForHits();
@@ -93,7 +135,7 @@ void Ai::think()
             bullet=true;
             shoot=false;
          }
-         else 
+         else
             bullet=false;
          score=1e10;
       }
@@ -105,7 +147,7 @@ void Ai::think()
    }
    else
       rotateFramesNumber--;
-      
+
 }
 
 
@@ -152,13 +194,13 @@ AiSprite Ai::nextPosition(AiSprite sp,double mult)
             sp.y+=sfheight;
             sp.border=true;
          }
-      }      
+      }
    }
 
-   return sp; 
+   return sp;
 }
 
-void Ai::nextPositions(AiSprite sp,QMemArray<AiSprite> *a,int frames)
+void Ai::nextPositions(AiSprite sp,QVector<AiSprite> *a,int frames)
 {
    int i,num;
    double fmult=cfg->gamespeed*frames;
@@ -171,15 +213,15 @@ void Ai::nextPositions(AiSprite sp,QMemArray<AiSprite> *a,int frames)
 
 void Ai::calculateNextPositions()
 {
-   unsigned int i,j;
-   MineSprite *ms;
+   unsigned int i;
+   int j;
 
    j=(int)(calcPositionNumber[Options::aiDifficulty(playerNumber)]/cfg->gamespeed);
-   
+
    if(shipsNextPositions[0]->size() != j)
       for(i=0;i<2;i++)
          shipsNextPositions[i]->resize(j);
-   
+
    for(i=0;i<2;i++)
       nextPositions(ship[i]->toAiSprite(),shipsNextPositions[i],
                     calcFrameIncrement[Options::aiDifficulty(playerNumber)]);
@@ -190,13 +232,9 @@ void Ai::calculateNextPositions()
 
    for(i=0;i<2;i++)
    {
-      j=0;
-      ms=mines[i]->first();
-      while(ms)
+      for (j=0; j<mines[i]->size(); j++)
       {
-         (*(aiMines[i]))[j]=ms->toAiSprite();
-         ms=mines[i]->next();
-         j++;
+         (*(aiMines[i]))[j]=mines[i]->value(j)->toAiSprite();
       }
       mineNumber[i]=j;
    }
@@ -212,7 +250,7 @@ void Ai::tryShots()
 
    me=ship[playerNumber]->toAiSprite();
    rot=ship[playerNumber]->getRotation();
-   
+
        //Each 'frameIncrement' frames a shot is tried
    frameIncrement=(int)((2*M_PI/calcShotDirections[Options::aiDifficulty(playerNumber)])
                         /cfg->rotationSpeed);
@@ -243,7 +281,7 @@ void Ai::tryShots()
                   nr=rot+frameIncrement*f*cfg->rotationSpeed;
                else
                   nr=rot-frameIncrement*f*cfg->rotationSpeed;
-               
+
                nx=cos(nr);
                ny=sin(nr);
                shot.x=me.x+nx*SHOTDIST;
@@ -251,6 +289,7 @@ void Ai::tryShots()
                shot.dx=me.dx+nx*cfg->shotSpeed;
                shot.dy=me.dy+ny*cfg->shotSpeed;
                shot.sun=false;
+               shot.border=false;
 
                hit=firstObject(shot,f*frameIncrement,
                                calcFrameIncrement[Options::aiDifficulty(playerNumber)]);
@@ -284,7 +323,6 @@ Hit Ai::firstObject(AiSprite shot,int time,int frames)
    optime=shipsNextPositions[0]->size();
 
    num=optime-basetime;
-   
    if(num>0)
    {
       for(t=0;(t<num)&&(!hitfound)&&(!shot.sun);t++)
@@ -312,7 +350,7 @@ Hit Ai::firstObject(AiSprite shot,int time,int frames)
                   hit.playerNumber=i;
                   hit.hitTime=basetime*frames;
                   hit.distance=dist;
-               }    
+               }
                shiplastdist=dist;
             }
                 //other ship
@@ -331,7 +369,7 @@ Hit Ai::firstObject(AiSprite shot,int time,int frames)
                distx=(*(aiMines[i]))[m].x-shot.x;
                disty=(*(aiMines[i]))[m].y-shot.y;
                dist=distx*distx+disty*disty;
-               
+
                if(dist<hit.distance)
                {
                   hit.object=HMINE;
@@ -350,58 +388,69 @@ Hit Ai::firstObject(AiSprite shot,int time,int frames)
 
    return hit;
 }
- 
+
 void Ai::testForHits()
 {
    AiSprite shot;
-   unsigned int i;
+   int i,j;
    int m,p;
    BulletSprite *bullet;
    Hit *h;
    Hit hit;
    bool hitfound=false;
    double distance,dx,dy;
+   int listsize; // used for caching QtList::size()
 
    if(calculateCollisions>0)
    {
       calculateCollisions--;
-      h=objectsHitByShip.first();
-      while(h)
+      i=0;
+      listsize = objectsHitByShip.size();
+      while(i<listsize)
       {
+         h = objectsHitByShip[i];
          if(h->hitTime>0)
          {
             h->hitTime--;
-            h=objectsHitByShip.next();
+            i++;
          }
          else
          {
-            objectsHitByShip.remove();
-            h=objectsHitByShip.current();
+            objectsHitByShip.removeAt(i);
+            delete h;
+            listsize--;
          }
       }
-      h=minesHitByShot.first();
-      while(h)
+      i=0;
+      listsize = minesHitByShot.size();
+      while(i<listsize)
       {
+         h=minesHitByShot[i];
          if(h->hitTime>0)
          {
             h->hitTime--;
-            h=minesHitByShot.next();
+            i++;
          }
          else
          {
-            minesHitByShot.remove();
-            h=minesHitByShot.current();
+            minesHitByShot.removeAt(i);
+            delete h;
+            listsize--;
          }
       }
    }
    else
    {
+      qDeleteAll(objectsHitByShip);
       objectsHitByShip.clear();
+      qDeleteAll(minesHitByShot);
       minesHitByShot.clear();
       for(i=0;i<2;i++)
       {
-         for(bullet=bullets[i]->first();bullet;bullet=bullets[i]->next())
+         listsize = bullets[i]->size();
+         for (j=0; j<listsize; j++)
          {
+            bullet=bullets[i]->value(j);
             shot=bullet->toAiSprite();
             hit=firstObject(shot,0,calcFrameIncrement[Options::aiDifficulty(playerNumber)]);
             if(hit.object==HMINE)
@@ -420,13 +469,13 @@ void Ai::testForHits()
 
       hit.object=HNOTHING;
       hit.distance=400;
-   
+
       for(i=0;(i<shipsNextPositions[0]->size()) &&
              !(*shipsNextPositions[playerNumber])[i].sun;i++)
       {
          if((borderTime<0) && (*shipsNextPositions[playerNumber])[i].border)
             borderTime=i*calcFrameIncrement[Options::aiDifficulty(playerNumber)];
-      
+
          dx=(*shipsNextPositions[playerNumber])[i].x;
          dy=(*shipsNextPositions[playerNumber])[i].y;
          distance=dx*dx+dy*dy;
@@ -467,14 +516,18 @@ void Ai::shotScores()
    Hit *h,*mh;
    bool found,foundmh;
    double dist,dx,dy,fuel;
+   int i,j,k;
+   int listsize,listsize2; // used for caching QtList::size()
+
 
-   
    dx=(*shipsNextPositions[playerNumber])[0].x-(*shipsNextPositions[opponentNumber])[0].x;
    dy=(*shipsNextPositions[playerNumber])[0].y-(*shipsNextPositions[opponentNumber])[0].y;
    dist=dx*dx+dy*dy;
 
-   for(s=myShots.first();s;s=myShots.next())
+   listsize = myShots.size();
+   for (j=0; j<listsize; j++)
    {
+      s = myShots[j];
       fuel=(100-(ship[playerNumber]->getEnergy()-cfg->shotEnergyNeed));
       s->score=fuel*fuel/10 + s->hit.distance+s->hit.hitTime;
       if(dist > (75*75))
@@ -485,8 +538,9 @@ void Ai::shotScores()
       if(s->hit.object==HMINE)
       {
          found=false;
-         for(h=objectsHitByShip.first();h && !found;h=objectsHitByShip.next())
+         for (i=0; i<objectsHitByShip.size() && !found; i++)
          {
+            h=objectsHitByShip[i];
             if((h->object==HMINE)&&(h->playerNumber==s->hit.playerNumber)
                &&(h->objectNumber==s->hit.objectNumber))
                    //ship will hit a mine that will be hitten by the shot
@@ -498,12 +552,18 @@ void Ai::shotScores()
                else
                {
                   foundmh=false;
-                  for(mh=minesHitByShot.first();mh && !foundmh;mh=minesHitByShot.next())
+                  listsize2 = minesHitByShot.size();
+                  for (k=0; k<listsize2 && !foundmh; k++)
                   {
+                     mh = minesHitByShot[k];
                      if((mh->playerNumber==s->hit.playerNumber)
                         &&(mh->objectNumber==s->hit.objectNumber))
                             //another shot will hit the mine
                      {
+                     	/* FIXME: check (and understand) this function
+                     	   original version: "found" in for-clause, bot was never true
+                     	   foundmh set to false before but never changed */
+                     	foundmh = true;
                         if(mh->hitTime<s->hit.hitTime)
                            s->score+=500;
                         else
@@ -529,8 +589,8 @@ void Ai::chooseAction()
    bool rotateAndAccelerate=false;
    Hit *nextHit=0;
    int shotHitTime;
+   int i;
 
-   
    shotHitTime=1000000;
    nextHit=0;
 /*   for(h=objectsHitByShip.first();h;h=objectsHitByShip.next())
@@ -540,15 +600,14 @@ void Ai::chooseAction()
             nextHit=h;
             shotHitTime=h->hitTime;
             }*/
-   
    if((borderTime>0) || (sunTime>0) || (nextHit))
-   {   
+   {
       actualpos=ship[playerNumber]->toAiSprite();
       posangle=rectToAngle(actualpos.x,actualpos.y);
-      
+
       movephi=rectToAngle((*shipsNextPositions[playerNumber])[0].x,
                           (*shipsNextPositions[playerNumber])[0].y) - posangle;
-      
+
       phileft=movephi+cfg->rotationSpeed;
       phiright=movephi-cfg->rotationSpeed;
 
@@ -615,7 +674,7 @@ void Ai::chooseAction()
                torotate-=2*M_PI;
             framesleft=(int)(torotate/phileft+0.5);
          }
-         
+
          if(phiright>0)
             framesright=1000;
          else
@@ -626,7 +685,7 @@ void Ai::chooseAction()
                torotate+=2*M_PI;
             framesright=(int)(torotate/phiright+0.5);
          }
-      
+
          if(framesright<framesleft)
          {
             rotation=RRIGHT;
@@ -638,19 +697,23 @@ void Ai::chooseAction()
             rotateFramesNumber=framesleft;
          }
          shoot=false;
-         
+
       }
    }
    else
    {
-      
-      bestShot=0;   
-      for(s=myShots.first();s;s=myShots.next())
+      int listsize; // used for caching QtList::size()
+      bestShot=0;
+      listsize = myShots.size();
+      for (i=0; i<listsize; i++)
+      {
+         s=myShots[i];
          if(s->score<bestScore)
          {
             bestScore=s->score;
             bestShot=s;
          }
+      }
       if(bestShot)
       {
          if((bestScore<score)&&(bestScore<400))
@@ -661,7 +724,7 @@ void Ai::chooseAction()
             shoot=true;
             score=bestScore;
             calculateCollisions = 0;
-            waitShot=(int) rint( random.getDouble() * 
+            waitShot=(int) rint( random.getDouble() *
 	                         calcNextShot[Options::aiDifficulty(playerNumber)]
                                  /cfg->gamespeed);
          }
